# pylaprof
🚧 **Work in progress** 🚧

Actually already usable (check the *examples* directory) but not yet production
ready.

To install:
```
pip install pylaprof
```

(or just copy-paste the pylaprof directory where you need it)

Credits:
- This library is heavily inspired to [pprofile](
  https://github.com/vpelletier/pprofile).
